# name: pam_mount data function
# desc: default parameter data function pam_mount module
# auth: Kai Burghardt <wiz at KaiBurghardt.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent fdm=marker:

function pam_mount::data() {
	$params = {
		'pam_mount_package_name'        => $facts['os']['family'] ? {
			'Debian'                      => 'libpam-mount',
			'FreeBSD'                     => 'pam_mount',
			default                       => undef,
		},
		'pam_mount_package_version'     => 'present',
		
		'pam_mount_conf_path'           => $facts['os']['family'] ? {
			'Debian'                      => '/etc/security/pam_mount.conf.xml',
			'FreeBSD'                     => '/usr/local/etc/security/pam_mount.conf.xml',
			default                       => undef,
		},
		'pam_mount_conf_owner'          => $facts['os']['family'] ? {
			'Debian'                      => 'root',
			'FreeBSD'                     => 'root',
			default                       => 0,
		},
		'pam_mount_conf_group'          => $facts['os']['family'] ? {
			'Debian'                      => 'root',
			'FreeBSD'                     => 'wheel',
			default                       => 0,
		},
		'pam_mount_conf_mode'           => '0640',
		'pam_mount_conf_template'       => 'pam_mount/pam_mount.conf.xml.erb',
		'pam_mount_conf_validate_cmd'   => $facts['os']['family'] ? {
			'Debian'                      => '/usr/bin/xmllint --nonet --noout --loaddtd --valid --path /usr/share/xml/pam_mount/dtd/ %',
			default                       => undef,
		},
	}
	
	# automatically prepend module name in front of each key
	Hash($params.map |$key, $value| {
		["${module_name}::${key}", $value]
	})
}
# EOF
