# name: pam_mount parameters
# desc: parameter manifest for pam_mount module
# auth: Kai Burghardt <wiz at KaiBurghardt.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent:

class pam_mount::params {
	$pam_mount_package_name        = $facts['os']['family'] ? {
		'Debian'                      => 'libpam-mount',
		'FreeBSD'                     => 'pam_mount',
		default                       => undef,
	}
	$pam_mount_package_version     = present
	
	$pam_mount_conf_path           = $facts['os']['family'] ? {
		'Debian'                      => '/etc/security/pam_mount.conf.xml',
		'FreeBSD'                     => '/usr/local/etc/security/pam_mount.conf.xml',
		'OpenBSD'                     => '/etc/pam_mount.conf.xml',
		default                       => undef,
	}
	$pam_mount_conf_mode           = '0640'
	$pam_mount_conf_owner          = $facts['os']['family'] ? {
		'Debian'                      => 'root',
		'FreeBSD'                     => 'root',
		default                       => 0,
	}
	$pam_mount_conf_group          = $facts['os']['family'] ? {
		'Debian'                      => 'root',
		'FreeBSD'                     => 'wheel',
		default                       => 0,
	}
	
	if $facts['os']['family'] == 'Debian' {
		# note: --path is a $PATH kind variable
		# (hence of the form 'primaryLocation:secondaryDirectory:tertiaryDirectory')
		$pam_mount_conf_validate_cmd   = @(EOT/L)
				/usr/bin/xmllint --nonet --noout --loaddtd --valid \
				--path /usr/share/xml/pam_mount/dtd/ \
				%
				|-EOT
	} else {
		$pam_mount_conf_validate_cmd   = undef
	}
	
	# currently there are two templates:
	# - one that is logically arranged, but does not validate with the DTD
	# - one that is arranged illogically, but does validate
	$pam_mount_conf_template       = ($pam_mount_conf_validate_cmd == undef) ? {
		false                         => 'pam_mount/pam_mount.conf.xml.erb',
		default                       => 'pam_mount/pam_mount_conf_xml.erb',
	}
}
# EOF
